/*
* This file is part of fwmon
* Copyright (c) 2001,2002 Gianni Tedesco
*
*    fwmon is free software; you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation; either version 2 of the License, or
*    (at your option) any later version.
*
*    fwmon is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with fwmon; if not, write to the Free Software
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#ifndef __G_GLOBALS_INCLUDED__
#define __G_GLOBALS_INCLUDED__

#define VERSION_STRING "Firewall Monitor (fwmon) v1.1.0" CRLF COPYRIGHT_STRING
#define COPYRIGHT_STRING "Copyright (c) 2001,2002 Gianni Tedesco" CRLF \
			"Released under the terms of the GNU GPL Version 2"

#include <sys/types.h>

#include <netinet/in.h>
#include <netinet/ip.h>
#include <netinet/udp.h>
#include <netinet/tcp.h>

#include <net/if.h>

#include <arpa/inet.h>

#include <stdlib.h>
#include <stdarg.h>
#include <stdio.h>

#include <string.h>
#include <unistd.h>
#include <netdb.h>
#include <fcntl.h>
#include <unistd.h>

#define _BSD_SRC
#include <grp.h>

#include "lang.h"

#define BUFFER_SIZE 4096

#define print_err(x, arg...) fprintf(stderr, x, ## arg);

struct icmphdr {
	unsigned char type;
	unsigned char code;
	unsigned short csum;
	unsigned short id;
	unsigned short seq;
}icmphdr;

typedef struct netlink_t {
	unsigned int len;
	unsigned int mark;
	char iface[IFNAMSIZ];
}netlink_t;

struct data_t{
	struct netlink_t netlink;
	unsigned char  data[BUFFER_SIZE];
};

typedef struct packet_t{
	/* timestamp */
	struct timeval ts;

	/* pointers to data */
	struct netlink_t *hdr;
	struct iphdr *ip;
	void *trans;
	void *app;
}packet_t, *p_packet;

typedef int (*cap_open)(void);
typedef int (*cap_close)(void);
typedef void (*cap_mainloop)(void);

#define flag(x) (globals.flags & x)
#define flag_set(x) globals.flags |= x
#define flag_unset(x) globals.flags &= ~x

#define err(x) (globals.error & x)
#define err_set(x) globals.error |= x
#define err_unset(x) globals.error &= ~x

#define FLAG_NONE	0x00000000
#define FLAG_DAEMON	0x00000001	/* Go to daemon mode */
#define FLAG_STDOUT	0x00000002	/* Print to stdout */
#define FLAG_LOGFILE	0x00000004	/* globals.logfile is valid */
#define FLAG_LIBPCAP	0x00000008	/* globals.pcapfile is valid */
#define FLAG_SUID	0x00000010	/* globals.uid is valid */
#define FLAG_SGID	0x00000020	/* globals.gid is valid */
#define FLAG_CHROOT	0x00000040	/* globals.chroot is valid */
#define FLAG_DROPROOT	0x00000080	/* a non root uid/gid is set */
#define FLAG_SHOWDATE	0x00000100	/* show the date on logged lines? */
#define FLAG_NODATA	0x00000200	/* don't dump data */
#define FLAG_NOHEX	0x00000400	/* don't show hex output */
#define FLAG_NOASCII	0x00000800	/* don't show ascii output */
#define FLAG_SYSLOG	0x00001000	/* log to system log */
#define FLAG_SQL	0x00002000	/* Log to SQL */
#define FLAG_SNIFFER	0x00004000	/* Sniffer mode */

#define ERROR_SUGID	0x00000001	/* uid or gid set, but not both */
#define ERROR_FMATCH	0x00000002	/* pcap and logfile are the same */
#define ERROR_NODATA	0x00000004	/* nohex and noascii */
#define ERROR_ZEROLINE	0x00000008	/* zero line length */
#define ERROR_LIBPCAP	0x00000010	/* No libpcap support */
#define ERROR_UNAME	0x00000020	/* Couldn't determine uname */
#define ERROR_NOOUT	0x00000040	/* No output specified */

#define LINE_LENGTH 16

typedef struct globals_t {
	unsigned long flags;
	unsigned long error;
	int 	nosync;
	uid_t	uid;
	gid_t	gid;
	char 	*chroot;
	char 	*logfile;
	char 	*pcapfile;
	int 	length;
	char 	*uname;
}globals_t;

extern struct globals_t globals;

#endif /* __G_GLOBALS_INCLUDED__ */

